summaryrefslogtreecommitdiff
path: root/src/game/game_instance.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/game_instance.cpp')
-rw-r--r--src/game/game_instance.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/game/game_instance.cpp b/src/game/game_instance.cpp
index abd054115..47374525f 100644
--- a/src/game/game_instance.cpp
+++ b/src/game/game_instance.cpp
@@ -82,12 +82,13 @@ void GameInstance::Died()
/**
* DoCommand callback function for all commands executed by Game Scripts.
* @param result The result of the command.
+ * @param cmd cmd as given to DoCommandPInternal.
* @param tile The tile on which the command was executed.
* @param p1 p1 as given to DoCommandPInternal.
* @param p2 p2 as given to DoCommandPInternal.
* @param cmd cmd as given to DoCommandPInternal.
*/
-void CcGame(const CommandCost &result, TileIndex tile, uint32 p1, uint32 p2, Commands cmd)
+void CcGame(const CommandCost &result, Commands cmd, TileIndex tile, uint32 p1, uint32 p2, const std::string &text)
{
if (Game::GetGameInstance()->DoCommandCallback(result, tile, p1, p2, cmd)) {
Game::GetGameInstance()->Continue();
@@ -82,12 +82,13 @@ void GameInstance::Died()
* @param p1 p1 as given to DoCommandPInternal.
* @param p2 p2 as given to DoCommandPInternal.
- * @param cmd cmd as given to DoCommandPInternal.
+ * @param text text as given to DoCommandPInternal.
*/